==> adsmanager-facade-3.3.3-sources.jar: com/bxm/adsmanager/facade/model/precharge/PrechargeDTO.java <==
package com.bxm.adsmanager.facade.model.precharge;


/**
 * @author tangx
 * @date 2020/5/12 17:06
 */
public class PrechargeDTO {

    private Long id;

    /**
     * 账户名称
     */
    private String accountName;

    /**
     * 绑定平台 1.变现猫-流量预充
     */
    private Byte bindingPlatform;

    /**
     * 开发者配置
     */
    private String providers;

    /**
     * 合同编号
     */
    private String contractNum;

    /**
     * 合同主体
     */
    private String contractSubject;

    /**
     * 合同开始时间
     */
    private String contractStartDate;

    /**
     * 合同结束时间
     */
    private String contractEndDate;


    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getAccountName() {
        return accountName;
    }

    public void setAccountName(String accountName) {
        this.accountName = accountName;
    }

    public Byte getBindingPlatform() {
        return bindingPlatform;
    }

    public void setBindingPlatform(Byte bindingPlatform) {
        this.bindingPlatform = bindingPlatform;
    }

    public String getProviders() {
        return providers;
    }

    public void setProviders(String providers) {
        this.providers = providers;
    }

    public String getContractNum() {
        return contractNum;
    }

    public void setContractNum(String contractNum) {
        this.contractNum = contractNum;
    }

    public String getContractSubject() {
        return contractSubject;
    }

    public void setContractSubject(String contractSubject) {
        this.contractSubject = contractSubject;
    }

    public String getContractStartDate() {
        return contractStartDate;
    }

    public void setContractStartDate(String contractStartDate) {
        this.contractStartDate = contractStartDate;
    }

    public String getContractEndDate() {
        return contractEndDate;
    }

    public void setContractEndDate(String contractEndDate) {
        this.contractEndDate = contractEndDate;
    }

    public static class ProviderDTO {

        private Integer id;

        private String appKey;

        private String startDate;

        private String endDate;

        public Integer getId() {
            return id;
        }

        public void setId(Integer id) {
            this.id = id;
        }

        public String getAppKey() {
            return appKey;
        }

        public void setAppKey(String appKey) {
            this.appKey = appKey;
        }

        public String getStartDate() {
            return startDate;
        }

        public void setStartDate(String startDate) {
            this.startDate = startDate;
        }

        public String getEndDate() {
            return endDate;
        }

        public void setEndDate(String endDate) {
            this.endDate = endDate;
        }
    }
}

==> adsmanager-facade-3.3.7.11-sources.jar: com/bxm/adsmanager/facade/model/precharge/PrechargeDTO.java <==
package com.bxm.adsmanager.facade.model.precharge;


/**
 * @author tangx
 * @date 2020/5/12 17:06
 */
public class PrechargeDTO {

    private Long id;

    /**
     * 账户名称
     */
    private String accountName;

    /**
     * 绑定平台 1.变现猫-流量预充
     */
    private Byte bindingPlatform;

    /**
     * 开发者配置
     */
    private String providers;

    /**
     * 合同编号
     */
    private String contractNum;

    /**
     * 合同主体
     */
    private String contractSubject;

    /**
     * 合同开始时间
     */
    private String contractStartDate;

    /**
     * 合同结束时间
     */
    private String contractEndDate;


    /**
     * 账户邮箱
     */
    private String accountEmail;

    /**
     * 抄送邮箱，多个用逗号分隔
     */
    private String ccEmail;

    /**
     * 媒体名称
     */
    private String mediaName;


    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getAccountName() {
        return accountName;
    }

    public void setAccountName(String accountName) {
        this.accountName = accountName;
    }

    public Byte getBindingPlatform() {
        return bindingPlatform;
    }

    public void setBindingPlatform(Byte bindingPlatform) {
        this.bindingPlatform = bindingPlatform;
    }

    public String getProviders() {
        return providers;
    }

    public void setProviders(String providers) {
        this.providers = providers;
    }

    public String getContractNum() {
        return contractNum;
    }

    public void setContractNum(String contractNum) {
        this.contractNum = contractNum;
    }

    public String getContractSubject() {
        return contractSubject;
    }

    public void setContractSubject(String contractSubject) {
        this.contractSubject = contractSubject;
    }

    public String getContractStartDate() {
        return contractStartDate;
    }

    public void setContractStartDate(String contractStartDate) {
        this.contractStartDate = contractStartDate;
    }

    public String getContractEndDate() {
        return contractEndDate;
    }

    public void setContractEndDate(String contractEndDate) {
        this.contractEndDate = contractEndDate;
    }

    public static class ProviderDTO {

        private Integer id;

        private String appKey;

        private String startDate;

        private String endDate;

        public Integer getId() {
            return id;
        }

        public void setId(Integer id) {
            this.id = id;
        }

        public String getAppKey() {
            return appKey;
        }

        public void setAppKey(String appKey) {
            this.appKey = appKey;
        }

        public String getStartDate() {
            return startDate;
        }

        public void setStartDate(String startDate) {
            this.startDate = startDate;
        }

        public String getEndDate() {
            return endDate;
        }

        public void setEndDate(String endDate) {
            this.endDate = endDate;
        }
    }

    public String getAccountEmail() {
        return accountEmail;
    }

    public void setAccountEmail(String accountEmail) {
        this.accountEmail = accountEmail;
    }

    public String getCcEmail() {
        return ccEmail;
    }

    public void setCcEmail(String ccEmail) {
        this.ccEmail = ccEmail;
    }

    public String getMediaName() {
        return mediaName;
    }

    public void setMediaName(String mediaName) {
        this.mediaName = mediaName;
    }
}
